@@ -234,6 +234,8 @@ class Highscores(abc.Serializable):
             cols_raw = row.find_all('td')
             if "There is currently no data" in cols_raw[0].text:
                 break
+            if cols_raw[0].text == "Rank":
+                continue
             if len(cols_raw) <= 2:
                 break
             self._parse_entry(cols_raw)
